// CourseList.tsx
import { motion } from "framer-motion";
import { Course, CourseDto } from "@nicestack/common";
import { EmptyState } from "@web/src/components/presentation/space/Empty";
interface CourseListProps {
    courses: CourseDto[];
    activeTab: "enrolled" | "created";
}
const container = {
    hidden: { opacity: 0 },
    show: {
        opacity: 1,
        transition: {
            staggerChildren: 0.05,
            duration: 0.3
        },
    },
};
export const CourseList = ({
    courses,
    renderItem,
    emptyComponent: EmptyComponent,
}: CourseListProps & {
    renderItem?: (course: CourseDto) => React.ReactNode;
    emptyComponent?: React.ReactNode;
}) => {
    if (courses.length === 0) {
        return EmptyComponent || (
            <EmptyState />
        );
    }
    return (
        <motion.div
            variants={container}
            initial="hidden"
            animate="show"
            className="grid gap-6 sm:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4"
        >
            {courses.map((course) => renderItem(course))}
        </motion.div>
    );
};